import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D
from Engineering_tools import laval_nozzle


"""inputs for tests"""
gamma = 1.4 # ratio of specific heats
r = 287     # specific gas constant (J.Kg-1.K-1)

Pt = 20e5   # total pressure in the combustion chambre (Pa)
Tt = 2000   # total temperature in the combustion chambre (K)

Ath = 1   # throat section area (m2)
Ae = 2    # exit section area (m2)

    
"""call computation"""
data_final = pd.DataFrame(columns=['Pamb','Ath','Thrust','isp'])

Pamb_tab = np.linspace(1e5,1e2,200) # array of the ambient pressure (Pa)
Ath_tab = np.linspace(0.1,1.5,20) # array of the  throat section area (m2)
for Pamb in Pamb_tab:
    for Ath in Ath_tab:
        data_final.loc[len(data_final)] = (Pamb, Ath)+laval_nozzle(Pt,Tt,Pamb,Ath,Ae,gamma,r)
        
thrust=data_final['Thrust'].values.reshape(200,20)
isp=data_final['isp'].values.reshape(200,20)
X, Y = np.meshgrid(Ae/Ath_tab, Pamb_tab*1e-5)


"""figs and stuff"""
fig_thrust = plt.figure(1)
ax_thrust = fig_thrust.gca(projection='3d')
surf = ax_thrust.plot_surface(X, Y, thrust*1e-3)
plt.title('Thrust Vs Ambient Pressure Vs Section Area Ratio')
plt.xlabel('Section Area Ratio (Exit over Throat)')
plt.ylabel('Ambient Pressure (bar)')
#plt.zlabel('Thrust (kN)')
plt.show()

fig_isp = plt.figure(2)
ax_isp = fig_isp.gca(projection='3d')
surf = ax_isp.plot_surface(X, Y, isp)
plt.title('Isp Vs Ambient Pressure Vs Section Area Ratio')
plt.xlabel('Section Area Ratio (Exit over Throat)')
plt.ylabel('Ambient Pressure (bar)')
#plt.zlabel('Isp (s)')
plt.show()

plt.figure('Laval Nozzle: Thrust vs Ambiant Pressure')
plt.plot(Pamb_tab*1e-5,thrust[:,10]*1e-3)
plt.title('Thrust Vs Ambient Pressure')
plt.xlabel('Ambient Pressure (bar)')
plt.ylabel('Thrust (kN)')
plt.show()

plt.figure('Laval Nozzle: Isp vs Ambiant Pressure')
plt.plot(Pamb_tab*1e-5,isp[:,10])
plt.title('Isp Vs Ambient Pressure')
plt.xlabel('Ambient Pressure (bar)')
plt.ylabel('Isp (s)')
plt.show()

plt.figure('Laval Nozzle: Thrust vs Area Ratio')
plt.plot(Ath_tab,thrust[100,:]*1e-3)
plt.title('Thrust vs Area Ratio')
plt.xlabel('Section Area Ratio')
plt.ylabel('Thrust (kN)')
plt.show()

plt.figure('Laval Nozzle: Isp vs Area Ratio')
plt.plot(Ath_tab,isp[100,:])
plt.title('Isp vs Area Ratio')
plt.xlabel('Section Area Ratio')
plt.ylabel('Isp (s)')
plt.show()
